"""
    EMIL BillingService

    The EMIL BillingService API description  # noqa: E501

    The version of the OpenAPI document: 1.0
    Contact: kontakt@emil.de
    Generated by: https://openapi-generator.tech
"""


import unittest

import eis.billing
from eis.billing.api.estimated_invoices_api import EstimatedInvoicesApi  # noqa: E501


class TestEstimatedInvoicesApi(unittest.TestCase):
    """EstimatedInvoicesApi unit test stubs"""

    def setUp(self):
        self.api = EstimatedInvoicesApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_custom_estimated_invoice(self):
        """Test case for create_custom_estimated_invoice

        Create the custom estimated invoice  # noqa: E501
        """
        pass

    def test_create_estimated_invoice(self):
        """Test case for create_estimated_invoice

        Create the estimated invoice  # noqa: E501
        """
        pass

    def test_create_estimated_invoice_from_interval(self):
        """Test case for create_estimated_invoice_from_interval

        Create the estimated invoice  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
